==> rc-radio-1.0.1.tgz: package/README.md <==
# rc-rc-radio

react rc-radio component

[![NPM version][npm-image]][npm-url]
[![build status][travis-image]][travis-url]
[![Test coverage][coveralls-image]][coveralls-url]
[![gemnasium deps][gemnasium-image]][gemnasium-url]
[![node version][node-image]][node-url]
[![npm download][download-image]][download-url]

[npm-image]: http://img.shields.io/npm/v/rc-radio.svg?style=flat-square
[npm-url]: http://npmjs.org/package/rc-radio
[travis-image]: https://img.shields.io/travis/react-component/rc-radio.svg?style=flat-square
[travis-url]: https://travis-ci.org/react-component/rc-radio
[coveralls-image]: https://img.shields.io/coveralls/react-component/rc-radio.svg?style=flat-square
[coveralls-url]: https://coveralls.io/r/react-component/rc-radio?branch=master
[gemnasium-image]: http://img.shields.io/gemnasium/react-component/rc-radio.svg?style=flat-square
[gemnasium-url]: https://gemnasium.com/react-component/rc-radio
[node-image]: https://img.shields.io/badge/node.js-%3E=_0.10-green.svg?style=flat-square
[node-url]: http://nodejs.org/download/
[download-image]: https://img.shields.io/npm/dm/rc-rc-radio.svg?style=flat-square
[download-url]: https://npmjs.org/package/rc-radio

## install

[![rc-radio](https://nodei.co/npm/rc-radio.png)](https://npmjs.org/package/rc-radio)

## Usage

```js
var Radio = require('rc-radio');
// use rc-radio
```

## Development

```
npm install
npm start
```

## Test Case

http://localhost:9090/tests/runner.html?coverage

## Coverage

http://localhost:9090/node_modules/rc-server/node_modules/node-jscover/lib/front-end/jscoverage.html?w=http://localhost:9090/tests/runner.html?coverage

## License

rc-rc-radio is released under the MIT license.

==> rc-radio-1.0.3.tgz: package/README.md <==
# rc-radio

react rc-radio component

[![NPM version][npm-image]][npm-url]
[![build status][travis-image]][travis-url]
[![Test coverage][coveralls-image]][coveralls-url]
[![gemnasium deps][gemnasium-image]][gemnasium-url]
[![node version][node-image]][node-url]
[![npm download][download-image]][download-url]

[npm-image]: http://img.shields.io/npm/v/rc-radio.svg?style=flat-square
[npm-url]: http://npmjs.org/package/rc-radio
[travis-image]: https://img.shields.io/travis/react-component/rc-radio.svg?style=flat-square
[travis-url]: https://travis-ci.org/react-component/rc-radio
[coveralls-image]: https://img.shields.io/coveralls/react-component/rc-radio.svg?style=flat-square
[coveralls-url]: https://coveralls.io/r/react-component/rc-radio?branch=master
[gemnasium-image]: http://img.shields.io/gemnasium/react-component/rc-radio.svg?style=flat-square
[gemnasium-url]: https://gemnasium.com/react-component/rc-radio
[node-image]: https://img.shields.io/badge/node.js-%3E=_0.10-green.svg?style=flat-square
[node-url]: http://nodejs.org/download/
[download-image]: https://img.shields.io/npm/dm/rc-radio.svg?style=flat-square
[download-url]: https://npmjs.org/package/rc-radio

## install

[![rc-radio](https://nodei.co/npm/rc-radio.png)](https://npmjs.org/package/rc-radio)

## Usage

```js
var Radio = require('rc-radio');
// use rc-radio
```

## Development

```
npm install
npm start
```

## Test Case

http://localhost:9090/tests/runner.html?coverage

## Coverage

http://localhost:9090/node_modules/rc-server/node_modules/node-jscover/lib/front-end/jscoverage.html?w=http://localhost:9090/tests/runner.html?coverage

## License

rc-radio is released under the MIT license.
